Installation

# 1 Installation

There are three approaches to using `NanoCap`:

1. As a standalone application.

2. From source without rendering/GUI capabilities

3. From source with rendering/GUI capabilities

The installation procedures involved in each of the options above vary with increasing complexity yet this is balanced with an increase in versatility. For example, `NanoCap` compiled from source with with rendering and GUI capabilities can be used in parallelised code to produce and visualise multiple structures.

- 1.1 Requirements
- 1.2 Installing from source